#ifndef MOO_APP_WINDOW_H
#define MOO_APP_WINDOW_H

#include <QDialog>
#include <QMainWindow>
#include <QAction>
#include <moo/windowmenu.h>

class QPrinter;
class QPrintDialog;

namespace moo {

class WindowMenu;
class AppWindowPrivate;
class AppWindow : public QMainWindow {
    Q_OBJECT
    AppWindowPrivate *impl;

public:
    static QList<AppWindow*> listWindows();
    WindowMenu *windowMenu();

    // XXX
    static void allApplyPrefs();

    Q_INVOKABLE void showMessage(const QString &msg);
    Q_INVOKABLE void clearMessage();

protected:
    AppWindow(const QString &name);
    ~AppWindow();

    virtual void initUi();
    virtual void loadUiConfig();
    virtual void saveUiConfig();
    virtual void applyPrefs();

    void closeEvent(QCloseEvent *event);

    void connectAction(const char *action, const char *slot);
    void connectAction(QAction *action, const char *slot);
    void connectAction(const char *action, QObject *receiver, const char *slot);
    void connectAction(QAction *action, QObject *receiver, const char *slot);

    void setActionShortcuts(const char *action, const QList<QKeySequence> &shortcuts);
    void setActionShortcuts(const char *action, QKeySequence::StandardKey key);

protected:
    virtual void printDocument(QPrinter *printer);
    virtual void setupPrintDialog(QPrintDialog *dlg);

    virtual void showEvent(QShowEvent *event);

protected Q_SLOTS:
    void setWindowFileUrl(const QUrl &url);
    void setWindowModified(bool modified);
    void setWindowTitle(const QString &title);

private Q_SLOTS:
    void zoomWindow();

    void slotPrint();
    void slotPrintPreview();
    void slotPageSetup();

private Q_SLOTS:
    void slotPreviewPaintRequested(QPrinter *printer);

Q_SIGNALS:
    // FIXME Qt should have these
    void windowTitleChanged(const QString &newTitle);
    void windowFileUrlChanged(const QUrl &newUrl);
    void windowModifiedChanged(bool modified);
};

}

#endif // MOO_APP_WINDOW_H
