#ifndef MOO_DIALOGS_H
#define MOO_DIALOGS_H

#include <QMessageBox>
#include <QPointer>
#include <QString>
#include <QUrl>

namespace moo {

class NiceDialog : public QDialog {
    Q_OBJECT

    template<typename T>
    static T *createDialog(QWidget *parent)
    {
        T *dlg = new T(parent);
        dlg->show();
        dlg->raise();
        dlg->activateWindow();
        return dlg;
    }

private Q_SLOTS:
    void quit();

protected:
    NiceDialog(QWidget *parent);
    ~NiceDialog();

    template<typename T>
    static void showDialog(QPointer<T> &dlg, QWidget *parent)
    {
        if (!dlg)
        {
            dlg = createDialog<T>(parent);
        }
        else
        {
            dlg->raise();
            dlg->activateWindow();
        }
    }
};

class DocumentWindow;

namespace dlg {

struct FileFilterInfo {
    QString filter;
    QString name;
    FileFilterInfo(){}
    FileFilterInfo(const QString &filter, const QString &name) :
        filter(filter),
        name(name)
    {
    }
};

struct FileExtensionInfo {
    QString extension;
    QString name;
    FileExtensionInfo(){}
    FileExtensionInfo(const QString &ext, const QString &name) :
        extension(ext),
        name(name)
    {
    }
};

QList<QUrl> openFileNames(DocumentWindow *window, const QList<FileFilterInfo> &filters);
QUrl saveFileName(DocumentWindow *window, const QList<FileExtensionInfo> &extensions, FileExtensionInfo *ext);

QMessageBox::StandardButton information(QWidget *parent,
                                        const QString &title,
                                        const QString &text,
                                        const QString &secondaryText = QString(),
                                        QMessageBox::StandardButtons buttons = QMessageBox::Ok,
                                        QMessageBox::StandardButton defaultButton = QMessageBox::NoButton);

QString exeFileName(QWidget *parent, const QString &title, const QString &start);
QString dirName(QWidget *parent, const QString &title, const QString &start);

void openError(QWidget *window, const QString &filename, const QString &error);
void saveError(QWidget *window, const QString &filename, const QString &error);

// deleteOnClose set
QMessageBox *saveChanges(QWidget *window);

}

}

#endif // MOO_DIALOGS_H
